@@ -3,16 +3,13 @@ from collections.abc import Iterable
 from collections.abc import Iterator
 from collections.abc import Sequence
 
+from cutty.filestorage.domain.files import File
+from cutty.filestorage.domain.files import loadfile
 from cutty.filesystems.domain.path import Path
 from cutty.templates.domain.bindings import Binding
-from cutty.templates.domain.files import File
 from cutty.templates.domain.render import Renderer
 
 
-class InvalidPathComponent(Exception):
-    """The rendered path has an invalid component."""
-
-
 def renderfiles(
     paths: Iterable[Path], render: Renderer, bindings: Sequence[Binding]
 ) -> Iterator[File]:
@@ -25,13 +22,13 @@ def renderfiles(
                 continue
 
             if "/" in name or "\\" in name or name in (".", ".."):
-                raise InvalidPathComponent(str(path), name)
+                raise RuntimeError(
+                    f"invalid component {name!r} from {path.name!r} in {path}"
+                )
 
-            if path.is_file():
-                yield render(File.load(path), bindings)
-            elif path.is_dir():
+            if path.is_dir():
                 yield from _renderfiles(path.iterdir())
-            else:  # pragma: no cover
-                raise RuntimeError(f"{path}: not a regular file or directory")
+            else:
+                yield render(loadfile(path), bindings)
 
     return _renderfiles(paths)
